@@ -200,6 +200,9 @@ class Microservices(BaseClass, ABC):
                     self.end_headers()
                     self.wfile.write(message.encode('utf-8'))
 
+                def log_message(self, format, *args):
+                    return
+
             self.logs.info('[HealthCheck] listening on 0.0.0.0:80')
 
             server = HTTPServer(('', 80), myHandler)
